@@ -55,10 +55,12 @@ register_openers()
 class SdbError(Exception):
     def __init__(self, m):
         self.message = m
+    
 
 class UnexpectedResultError(Exception):
     def __init__(self, m):
         self.message = m
+    
 
 
 class SimpleDropbox(object):
@@ -304,11 +306,11 @@ class SimpleDropbox(object):
             return []
         
         soup = BeautifulSoup(pdata, convertEntities=BeautifulSoup.HTML_ENTITIES)
-        s_files = soup.findAll(attrs={'class':'browse-file-box-details'})
+        s_files = soup.findAll(attrs={'class':re.compile(r'\bbrowse-file-box-details\b')})
         f_files = []
         
         for s_file in s_files:
-            file_el = s_file.find(attrs={'class':'details-filename'}).a
+            file_el = s_file.find(attrs={'class':re.compile(r'\bdetails-filename\b')}).a
             browse_path = dict(file_el.attrs)['href']
             
             if browse_path[0:14] == u'/browse_plain/':
@@ -432,7 +434,8 @@ class SimpleDropbox(object):
         return f, pdata
     
     def stat(self, path):
-        """Get a single file's info.
+        """
+        Get a single file's info.
         
         Returns a SdFile object.
         
@@ -454,6 +457,7 @@ class SimpleDropbox(object):
         class Req(urllib2.Request):
             def get_method(self):
                 return 'HEAD'
+            
         
         headers = self.default_headers.copy()
         req = Req(url=url, headers=headers)
@@ -524,7 +528,8 @@ class SimpleDropbox(object):
     # ################ cmd() based commands
     
     def cp(self, files, to):
-        """Copy one or more files to a single destination.
+        """
+        Copy one or more files to a single destination.
         
         :param files: a list of items convertible to unicode
         :param to: an object convertible to unicode, hopefully a directory
@@ -552,7 +557,8 @@ class SimpleDropbox(object):
             raise UnexpectedResultError(u"Expected 'ok', got: %s" % (res,))
     
     def mv(self, files, to):
-        """Move one or more files to a single destination.
+        """
+        Move one or more files to a single destination.
         
         :param files: a list of items convertible to unicode
         :param to: an object convertible to unicode, hopefully a directory
@@ -581,7 +587,8 @@ class SimpleDropbox(object):
         
     
     def rm(self, files):
-        """Delete one or more files.
+        """
+        Delete one or more files.
         
         :param files: a list of items convertible to unicode
         
@@ -650,7 +657,8 @@ class SimpleDropbox(object):
         return node
     
     def mkdir(self, path):
-        """Create a directory.
+        """
+        Create a directory.
         
         :param path: an object convertible to unicode
         
